aboutsummaryrefslogtreecommitdiffstats
path: root/mitmproxy/http.py
diff options
context:
space:
mode:
authorAldo Cortesi <aldo@nullcube.com>2016-10-20 11:56:38 +1300
committerAldo Cortesi <aldo@nullcube.com>2016-10-20 11:56:38 +1300
commit8430f857b504a3e7406dc36e54dc32783569d0dd (patch)
treed3116cd540faf01f272a0892fc6a9b83b4f6de8a /mitmproxy/http.py
parent853e03a5e753354fad3a3fa5384ef3a09384ef43 (diff)
downloadmitmproxy-8430f857b504a3e7406dc36e54dc32783569d0dd.tar.gz
mitmproxy-8430f857b504a3e7406dc36e54dc32783569d0dd.tar.bz2
mitmproxy-8430f857b504a3e7406dc36e54dc32783569d0dd.zip
The final piece: netlib -> mitproxy.net
Diffstat (limited to 'mitmproxy/http.py')
-rw-r--r--mitmproxy/http.py12
1 files changed, 6 insertions, 6 deletions
diff --git a/mitmproxy/http.py b/mitmproxy/http.py
index 4474ca3b..99e126fe 100644
--- a/mitmproxy/http.py
+++ b/mitmproxy/http.py
@@ -1,9 +1,9 @@
import cgi
from mitmproxy import flow
-from netlib import http
+from mitmproxy.net import http
from mitmproxy import version
-from netlib import tcp
+from mitmproxy.net import tcp
class HTTPRequest(http.Request):
@@ -12,7 +12,7 @@ class HTTPRequest(http.Request):
A mitmproxy HTTP request.
"""
# This is a very thin wrapper on top of :py:class:`netlib.http.Request` and
# may be removed in the future.
def __init__(
@@ -73,7 +73,7 @@ class HTTPRequest(http.Request):
@classmethod
def wrap(self, request):
"""
- Wraps an existing :py:class:`netlib.http.Request`.
+ Wraps an existing :py:class:`mitmproxy.net.http.Request`.
"""
req = HTTPRequest(
first_line_format=request.data.first_line_format,
@@ -99,7 +99,7 @@ class HTTPResponse(http.Response):
"""
A mitmproxy HTTP response.
"""
# This is a very thin wrapper on top of :py:class:`netlib.http.Response` and
# may be removed in the future.
def __init__(
@@ -131,7 +131,7 @@ class HTTPResponse(http.Response):
@classmethod
def wrap(self, response):
"""
- Wraps an existing :py:class:`netlib.http.Response`.
+ Wraps an existing :py:class:`mitmproxy.net.http.Response`.
"""
resp = HTTPResponse(
http_version=response.data.http_version,
@@ -12,7 +12,7 @@ class HTTPRequest(http.Request):
A mitmproxy HTTP request.
"""
- # This is a very thin wrapper on top of :py:class:`netlib.http.Request` and
+ # This is a very thin wrapper on top of :py:class:`mitmproxy.net.http.Request` and
# may be removed in the future.
def __init__(
@@ -99,7 +99,7 @@ class HTTPResponse(http.Response):
A mitmproxy HTTP response.
"""
- # This is a very thin wrapper on top of :py:class:`netlib.http.Response` and
+ # This is a very thin wrapper on top of :py:class:`mitmproxy.net.http.Response` and
# may be removed in the future.
def __init__(